@@ -14,9 +14,5 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# all imports are wrapped in try blocks for allowing of backwards compatibility.
-
-try:
-    from ...dyn.cui.color_picker import ColorPicker as ColorPicker
-except ImportError:
-    pass
+from ...dyn.cui.asynchronous_color_picker import AsynchronousColorPicker as AsynchronousColorPicker
+from ...dyn.cui.color_picker import ColorPicker as ColorPicker
